==> openshift-model-console-6.2.0-sources.jar: io/fabric8/openshift/api/model/console/v1alpha1/ConsolePluginProxyFluentImpl.java <==
package io.fabric8.openshift.api.model.console.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ConsolePluginProxyFluentImpl<A extends ConsolePluginProxyFluent<A>> extends BaseFluent<A> implements ConsolePluginProxyFluent<A>{
  public ConsolePluginProxyFluentImpl() {
  }
  public ConsolePluginProxyFluentImpl(ConsolePluginProxy instance) {
    this.withServices(instance.getServices()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private ArrayList<ConsolePluginProxyServiceBuilder> services = new ArrayList<ConsolePluginProxyServiceBuilder>();
  private Map<String,Object> additionalProperties;
  public A addToServices(Integer index,ConsolePluginProxyService item) {
    if (this.services == null) {this.services = new ArrayList<ConsolePluginProxyServiceBuilder>();}
    ConsolePluginProxyServiceBuilder builder = new ConsolePluginProxyServiceBuilder(item);_visitables.get("services").add(index >= 0 ? index : _visitables.get("services").size(), builder);this.services.add(index >= 0 ? index : services.size(), builder); return (A)this;
  }
  public A setToServices(Integer index,ConsolePluginProxyService item) {
    if (this.services == null) {this.services = new ArrayList<ConsolePluginProxyServiceBuilder>();}
    ConsolePluginProxyServiceBuilder builder = new ConsolePluginProxyServiceBuilder(item);
    if (index < 0 || index >= _visitables.get("services").size()) { _visitables.get("services").add(builder); } else { _visitables.get("services").set(index, builder);}
    if (index < 0 || index >= services.size()) { services.add(builder); } else { services.set(index, builder);}
     return (A)this;
  }
  public A addToServices(io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService... items) {
    if (this.services == null) {this.services = new ArrayList<ConsolePluginProxyServiceBuilder>();}
    for (ConsolePluginProxyService item : items) {ConsolePluginProxyServiceBuilder builder = new ConsolePluginProxyServiceBuilder(item);_visitables.get("services").add(builder);this.services.add(builder);} return (A)this;
  }
  public A addAllToServices(Collection<ConsolePluginProxyService> items) {
    if (this.services == null) {this.services = new ArrayList<ConsolePluginProxyServiceBuilder>();}
    for (ConsolePluginProxyService item : items) {ConsolePluginProxyServiceBuilder builder = new ConsolePluginProxyServiceBuilder(item);_visitables.get("services").add(builder);this.services.add(builder);} return (A)this;
  }
  public A removeFromServices(io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService... items) {
    for (ConsolePluginProxyService item : items) {ConsolePluginProxyServiceBuilder builder = new ConsolePluginProxyServiceBuilder(item);_visitables.get("services").remove(builder);if (this.services != null) {this.services.remove(builder);}} return (A)this;
  }
  public A removeAllFromServices(Collection<ConsolePluginProxyService> items) {
    for (ConsolePluginProxyService item : items) {ConsolePluginProxyServiceBuilder builder = new ConsolePluginProxyServiceBuilder(item);_visitables.get("services").remove(builder);if (this.services != null) {this.services.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromServices(Predicate<ConsolePluginProxyServiceBuilder> predicate) {
    if (services == null) return (A) this;
    final Iterator<ConsolePluginProxyServiceBuilder> each = services.iterator();
    final List visitables = _visitables.get("services");
    while (each.hasNext()) {
      ConsolePluginProxyServiceBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildServices instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ConsolePluginProxyService> getServices() {
    return services != null ? build(services) : null;
  }
  public List<ConsolePluginProxyService> buildServices() {
    return services != null ? build(services) : null;
  }
  public ConsolePluginProxyService buildService(Integer index) {
    return this.services.get(index).build();
  }
  public ConsolePluginProxyService buildFirstService() {
    return this.services.get(0).build();
  }
  public ConsolePluginProxyService buildLastService() {
    return this.services.get(services.size() - 1).build();
  }
  public ConsolePluginProxyService buildMatchingService(Predicate<ConsolePluginProxyServiceBuilder> predicate) {
    for (ConsolePluginProxyServiceBuilder item: services) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingService(Predicate<ConsolePluginProxyServiceBuilder> predicate) {
    for (ConsolePluginProxyServiceBuilder item: services) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withServices(List<ConsolePluginProxyService> services) {
    if (this.services != null) { _visitables.get("services").removeAll(this.services);}
    if (services != null) {this.services = new ArrayList(); for (ConsolePluginProxyService item : services){this.addToServices(item);}} else { this.services = null;} return (A) this;
  }
  public A withServices(io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService... services) {
    if (this.services != null) {this.services.clear();}
    if (services != null) {for (ConsolePluginProxyService item :services){ this.addToServices(item);}} return (A) this;
  }
  public Boolean hasServices() {
    return services != null && !services.isEmpty();
  }
  public A addNewService(Boolean authorize,String caCertificate,String name,String namespace,Integer port) {
    return (A)addToServices(new ConsolePluginProxyService(authorize, caCertificate, name, namespace, port));
  }
  public ConsolePluginProxyFluent.ServicesNested<A> addNewService() {
    return new ConsolePluginProxyFluentImpl.ServicesNestedImpl();
  }
  public ConsolePluginProxyFluent.ServicesNested<A> addNewServiceLike(ConsolePluginProxyService item) {
    return new ConsolePluginProxyFluentImpl.ServicesNestedImpl(-1, item);
  }
  public ConsolePluginProxyFluent.ServicesNested<A> setNewServiceLike(Integer index,ConsolePluginProxyService item) {
    return new ConsolePluginProxyFluentImpl.ServicesNestedImpl(index, item);
  }
  public ConsolePluginProxyFluent.ServicesNested<A> editService(Integer index) {
    if (services.size() <= index) throw new RuntimeException("Can't edit services. Index exceeds size.");
    return setNewServiceLike(index, buildService(index));
  }
  public ConsolePluginProxyFluent.ServicesNested<A> editFirstService() {
    if (services.size() == 0) throw new RuntimeException("Can't edit first services. The list is empty.");
    return setNewServiceLike(0, buildService(0));
  }
  public ConsolePluginProxyFluent.ServicesNested<A> editLastService() {
    int index = services.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last services. The list is empty.");
    return setNewServiceLike(index, buildService(index));
  }
  public ConsolePluginProxyFluent.ServicesNested<A> editMatchingService(Predicate<ConsolePluginProxyServiceBuilder> predicate) {
    int index = -1;
    for (int i=0;i<services.size();i++) { 
    if (predicate.test(services.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching services. No match found.");
    return setNewServiceLike(index, buildService(index));
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConsolePluginProxyFluentImpl that = (ConsolePluginProxyFluentImpl) o;
    if (services != null ? !services.equals(that.services) :that.services != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(services,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (services != null && !services.isEmpty()) { sb.append("services:"); sb.append(services + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class ServicesNestedImpl<N> extends ConsolePluginProxyServiceFluentImpl<ConsolePluginProxyFluent.ServicesNested<N>> implements ConsolePluginProxyFluent.ServicesNested<N>,Nested<N>{
    ServicesNestedImpl(Integer index,ConsolePluginProxyService item) {
      this.index = index;
      this.builder = new ConsolePluginProxyServiceBuilder(this, item);
    }
    ServicesNestedImpl() {
      this.index = -1;
      this.builder = new ConsolePluginProxyServiceBuilder(this);
    }
    ConsolePluginProxyServiceBuilder builder;
    Integer index;
    public N and() {
      return (N) ConsolePluginProxyFluentImpl.this.setToServices(index,builder.build());
    }
    public N endService() {
      return and();
    }
    
  }
  
}

==> openshift-model-console-6.7.2-sources.jar: io/fabric8/openshift/api/model/console/v1alpha1/ConsolePluginProxyFluentImpl.java <==
package io.fabric8.openshift.api.model.console.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ConsolePluginProxyFluentImpl<A extends ConsolePluginProxyFluent<A>> extends BaseFluent<A> implements ConsolePluginProxyFluent<A>{
  public ConsolePluginProxyFluentImpl() {
  }
  public ConsolePluginProxyFluentImpl(ConsolePluginProxy instance) {
    if (instance != null) {
      this.withServices(instance.getServices());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private ArrayList<ConsolePluginProxyServiceBuilder> services = new ArrayList<ConsolePluginProxyServiceBuilder>();
  private Map<String,Object> additionalProperties;
  public A addToServices(int index,ConsolePluginProxyService item) {
    if (this.services == null) {this.services = new ArrayList<ConsolePluginProxyServiceBuilder>();}
    ConsolePluginProxyServiceBuilder builder = new ConsolePluginProxyServiceBuilder(item);
    if (index < 0 || index >= services.size()) { _visitables.get("services").add(builder); services.add(builder); } else { _visitables.get("services").add(index, builder); services.add(index, builder);}
    return (A)this;
  }
  public A setToServices(int index,ConsolePluginProxyService item) {
    if (this.services == null) {this.services = new ArrayList<ConsolePluginProxyServiceBuilder>();}
    ConsolePluginProxyServiceBuilder builder = new ConsolePluginProxyServiceBuilder(item);
    if (index < 0 || index >= services.size()) { _visitables.get("services").add(builder); services.add(builder); } else { _visitables.get("services").set(index, builder); services.set(index, builder);}
    return (A)this;
  }
  public A addToServices(io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService... items) {
    if (this.services == null) {this.services = new ArrayList<ConsolePluginProxyServiceBuilder>();}
    for (ConsolePluginProxyService item : items) {ConsolePluginProxyServiceBuilder builder = new ConsolePluginProxyServiceBuilder(item);_visitables.get("services").add(builder);this.services.add(builder);} return (A)this;
  }
  public A addAllToServices(Collection<ConsolePluginProxyService> items) {
    if (this.services == null) {this.services = new ArrayList<ConsolePluginProxyServiceBuilder>();}
    for (ConsolePluginProxyService item : items) {ConsolePluginProxyServiceBuilder builder = new ConsolePluginProxyServiceBuilder(item);_visitables.get("services").add(builder);this.services.add(builder);} return (A)this;
  }
  public A removeFromServices(io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService... items) {
    for (ConsolePluginProxyService item : items) {ConsolePluginProxyServiceBuilder builder = new ConsolePluginProxyServiceBuilder(item);_visitables.get("services").remove(builder);if (this.services != null) {this.services.remove(builder);}} return (A)this;
  }
  public A removeAllFromServices(Collection<ConsolePluginProxyService> items) {
    for (ConsolePluginProxyService item : items) {ConsolePluginProxyServiceBuilder builder = new ConsolePluginProxyServiceBuilder(item);_visitables.get("services").remove(builder);if (this.services != null) {this.services.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromServices(Predicate<ConsolePluginProxyServiceBuilder> predicate) {
    if (services == null) return (A) this;
    final Iterator<ConsolePluginProxyServiceBuilder> each = services.iterator();
    final List visitables = _visitables.get("services");
    while (each.hasNext()) {
      ConsolePluginProxyServiceBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildServices instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ConsolePluginProxyService> getServices() {
    return services != null ? build(services) : null;
  }
  public List<ConsolePluginProxyService> buildServices() {
    return services != null ? build(services) : null;
  }
  public ConsolePluginProxyService buildService(int index) {
    return this.services.get(index).build();
  }
  public ConsolePluginProxyService buildFirstService() {
    return this.services.get(0).build();
  }
  public ConsolePluginProxyService buildLastService() {
    return this.services.get(services.size() - 1).build();
  }
  public ConsolePluginProxyService buildMatchingService(Predicate<ConsolePluginProxyServiceBuilder> predicate) {
    for (ConsolePluginProxyServiceBuilder item: services) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public Boolean hasMatchingService(Predicate<ConsolePluginProxyServiceBuilder> predicate) {
    for (ConsolePluginProxyServiceBuilder item: services) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withServices(List<ConsolePluginProxyService> services) {
    if (this.services != null) { _visitables.get("services").clear();}
    if (services != null) {this.services = new ArrayList(); for (ConsolePluginProxyService item : services){this.addToServices(item);}} else { this.services = null;} return (A) this;
  }
  public A withServices(io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService... services) {
    if (this.services != null) {this.services.clear(); _visitables.remove("services"); }
    if (services != null) {for (ConsolePluginProxyService item :services){ this.addToServices(item);}} return (A) this;
  }
  public Boolean hasServices() {
    return services != null && !services.isEmpty();
  }
  public A addNewService(Boolean authorize,String caCertificate,String name,String namespace,Integer port) {
    return (A)addToServices(new ConsolePluginProxyService(authorize, caCertificate, name, namespace, port));
  }
  public ConsolePluginProxyFluentImpl.ServicesNested<A> addNewService() {
    return new ConsolePluginProxyFluentImpl.ServicesNestedImpl();
  }
  public ConsolePluginProxyFluentImpl.ServicesNested<A> addNewServiceLike(ConsolePluginProxyService item) {
    return new ConsolePluginProxyFluentImpl.ServicesNestedImpl(-1, item);
  }
  public ConsolePluginProxyFluentImpl.ServicesNested<A> setNewServiceLike(int index,ConsolePluginProxyService item) {
    return new ConsolePluginProxyFluentImpl.ServicesNestedImpl(index, item);
  }
  public ConsolePluginProxyFluentImpl.ServicesNested<A> editService(int index) {
    if (services.size() <= index) throw new RuntimeException("Can't edit services. Index exceeds size.");
    return setNewServiceLike(index, buildService(index));
  }
  public ConsolePluginProxyFluentImpl.ServicesNested<A> editFirstService() {
    if (services.size() == 0) throw new RuntimeException("Can't edit first services. The list is empty.");
    return setNewServiceLike(0, buildService(0));
  }
  public ConsolePluginProxyFluentImpl.ServicesNested<A> editLastService() {
    int index = services.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last services. The list is empty.");
    return setNewServiceLike(index, buildService(index));
  }
  public ConsolePluginProxyFluentImpl.ServicesNested<A> editMatchingService(Predicate<ConsolePluginProxyServiceBuilder> predicate) {
    int index = -1;
    for (int i=0;i<services.size();i++) { 
    if (predicate.test(services.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching services. No match found.");
    return setNewServiceLike(index, buildService(index));
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ConsolePluginProxyFluentImpl that = (ConsolePluginProxyFluentImpl) o;
    if (!java.util.Objects.equals(services, that.services)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(services,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (services != null) { sb.append("services:"); sb.append(services + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class ServicesNestedImpl<N> extends ConsolePluginProxyServiceFluentImpl<ConsolePluginProxyFluentImpl.ServicesNested<N>> implements ConsolePluginProxyFluentImpl.ServicesNested<N>,Nested<N>{
    ServicesNestedImpl(int index,ConsolePluginProxyService item) {
      this.index = index;
      this.builder = new ConsolePluginProxyServiceBuilder(this, item);
    }
    ServicesNestedImpl() {
      this.index = -1;
      this.builder = new ConsolePluginProxyServiceBuilder(this);
    }
    ConsolePluginProxyServiceBuilder builder;
    int index;
    public N and() {
      return (N) ConsolePluginProxyFluentImpl.this.setToServices(index,builder.build());
    }
    public N endService() {
      return and();
    }
    
  }
  
}
